@@ -7,7 +7,10 @@ def crop(image,
          slider_text: str = "Slice",
          axis_names=None,
          zoom_factor: float = 1.0,
-         zoom_spline_order: int = 0):
+         zoom_spline_order: int = 0,
+         colormap:str = None,
+         display_min:float = None,
+         display_max:float = None):
     """
     Allows cropping an image along all axes.
 
@@ -29,8 +32,18 @@ def crop(image,
         Allows showing the image larger (> 1) or smaller (<1)
     zoom_spline_order: int, optional
         Spline order used for interpolation (default=0, nearest-neighbor)
+    colormap: str, optional
+        Matplotlib colormap name or "pure_green", "pure_magenta", ...
+    display_min: float, optional
+        Lower bound of properly shown intensities
+    display_max: float, optional
+        Upper bound of properly shown intensities
 
     """
+
+    if 'cupy.ndarray' in str(type(image)):
+        image = image.get()
+
     return _Cropper(image,
                     slice_number=slice_number,
                     axis=axis,
@@ -38,7 +51,10 @@ def crop(image,
                     slider_text=slider_text,
                     axis_names=axis_names,
                     zoom_factor=zoom_factor,
-                    zoom_spline_order=zoom_spline_order)
+                    zoom_spline_order=zoom_spline_order,
+                    colormap=colormap,
+                    display_min=display_min,
+                    display_max=display_max)
 
 
 class _Cropper(VBox):
@@ -55,7 +71,10 @@ class _Cropper(VBox):
                  slider_text: str = "Slice",
                  axis_names=None,
                  zoom_factor: float = 1.0,
-                 zoom_spline_order: int = 0):
+                 zoom_spline_order: int = 0,
+                 colormap:str = None,
+                 display_min:float = None,
+                 display_max:float = None):
         from ipywidgets import IntRangeSlider
         from ._slice_viewer import _SliceViewer
         from ._utilities import _no_resize
@@ -70,7 +89,10 @@ class _Cropper(VBox):
                               continuous_update,
                               slider_text,
                               zoom_factor=zoom_factor,
-                              zoom_spline_order=zoom_spline_order
+                              zoom_spline_order=zoom_spline_order,
+                              colormap=colormap,
+                              display_min=display_min,
+                              display_max=display_max
                               )
 
         if len(image.shape) < 2 or len(image.shape) > 3:
