@@ -7,6 +7,9 @@ def interact(func,
              context:dict = None,
              zoom_factor:float = 1.0,
              zoom_spline_order:int = 0,
+             colormap:str = None,
+             display_min:float = None,
+             display_max:float = None,
              viewer: _SliceViewer = None,
              **kwargs):
     """Takes a function which has an image as first parameter and additional parameters.
@@ -27,6 +30,12 @@ def interact(func,
         Allows showing the image larger (> 1) or smaller (<1)
     zoom_spline_order: int, optional
         Spline order used for interpolation (default=0, nearest-neighbor)
+    colormap: str, optional
+        Matplotlib colormap name or "pure_green", "pure_magenta", ...
+    display_min: float, optional
+        Lower bound of properly shown intensities
+    display_max: float, optional
+        Upper bound of properly shown intensities
     viewer: _SliceViewer, optional
         The viewer where the result image should be shown.
     kwargs
@@ -39,6 +48,10 @@ def interact(func,
     from ._utilities import _no_resize
     from ._slice_viewer import _SliceViewer
 
+    if 'cupy.ndarray' in str(type(image)):
+        image = image.get()
+
+
     # hidden feature: func can be a tuple of (function, alias_name)
     if isinstance(func, tuple):
         func_name = func[1]
@@ -61,7 +74,7 @@ def interact(func,
     for key in sig.parameters.keys():
         exposable = False
         default_value = 0
-        if isinstance(sig.parameters[key].default, int) or isinstance(sig.parameters[key].default, float):
+        if isinstance(sig.parameters[key].default, int) or isinstance(sig.parameters[key].default, float) or isinstance(sig.parameters[key].default, str):
             default_value = sig.parameters[key].default
         min_value, max_value, step = guess_range(key, sig.parameters[key].annotation)
 
@@ -76,7 +89,11 @@ def interact(func,
         if max_value is None:
             max_value = 100
 
-        if sig.parameters[key].annotation is int:
+        if sig.parameters[key].annotation is str:
+            default_value = ipywidgets.Text(value=default_value,
+                                       continuous_update=continuous_update)
+            exposable = True
+        elif sig.parameters[key].annotation is int:
             default_value = int_slider(min=min_value, max=max_value, step=step, value=default_value, continuous_update=continuous_update)
             exposable = True
         elif sig.parameters[key].annotation is float or 'sigma' in key or 'radius' in key:
@@ -105,7 +122,7 @@ def interact(func,
 
     viewer_was_none = viewer is None
     if viewer_was_none:
-        viewer = _SliceViewer(image, zoom_factor=zoom_factor, zoom_spline_order=zoom_spline_order)
+        viewer = _SliceViewer(image, zoom_factor=zoom_factor, zoom_spline_order=zoom_spline_order, colormap=colormap, display_min=display_min, display_max=display_max)
     viewer.slice_slider.continuous_update=continuous_update
     command_label = ipywidgets.Label(value=func_name + "()")
     command_label.style.font_family = "Courier"
