@@ -9,7 +9,10 @@ class _SliceViewer():
                  continuous_update: bool = True,
                  slider_text: str = "Slice",
                  zoom_factor:float = 1.0,
-                 zoom_spline_order:int = 0
+                 zoom_spline_order:int = 0,
+                 colormap:str = None,
+                 display_min:float = None,
+                 display_max:float = None
                  ):
         import ipywidgets
         from ._image_widget import ImageWidget
@@ -20,10 +23,16 @@ class _SliceViewer():
         if slice_number is None:
             slice_number = int(image.shape[axis] / 2)
 
-        if len(self.image.shape) == 3 and self.image.shape[-1] != 3:
-            self.view = ImageWidget(np.take(image, slice_number, axis=axis), zoom_factor=zoom_factor, zoom_spline_order=zoom_spline_order)
+        if len(self.image.shape) > 2: # and self.image.shape[-1] != 3:
+            sliced_image = np.take(image, slice_number, axis=axis)
         else:
-            self.view = ImageWidget(image, zoom_factor=zoom_factor, zoom_spline_order=zoom_spline_order)
+            sliced_image = image
+        self.view = ImageWidget(sliced_image,
+                                zoom_factor=zoom_factor,
+                                zoom_spline_order=zoom_spline_order,
+                                colormap=colormap,
+                                display_min=display_min,
+                                display_max=display_max)
 
         # setup user interface for changing the slice
         self.slice_slider = ipywidgets.IntSlider(
@@ -40,6 +49,11 @@ class _SliceViewer():
             if len(self.image.shape) == 3 and self.image.shape[-1] != 3:
                 self.slice_slider.layout.display = None
                 self.view.data = np.take(self.image, self.slice_slider.value, axis=axis)
+            elif len(self.image.shape) == 4 and self.image.shape[-1] == 3:
+                self.slice_slider.layout.display = None
+                self.view.data = np.take(self.image, self.slice_slider.value, axis=axis)
+            elif len(self.image.shape) == 4:
+                raise NotImplementedError("Only 2D and 3D images are supported" + str(image.shape))
             else:
                 self.view.data = self.image
                 self.slice_slider.layout.display = 'none'
